@@ -1,11 +1,11 @@
-# Copyrights 2006-2012 by [Mark Overmeer].
+# Copyrights 2006-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
  
 package XML::Compile::Translate::Writer;
 use vars '$VERSION';
-$VERSION = '1.30';
+$VERSION = '1.31';
 
 use base 'XML::Compile::Translate';
 
@@ -1014,7 +1014,9 @@ sub makeXsiTypeSwitch($$$$)
     foreach my $type (sort keys %$types)
     {   my ($ns, $local) = unpack_type $type;
         my $tag = $self->makeTagQualified($where, undef, $local, $ns);
-        $types{$type} = [ $tag, $types->{$type} ];
+
+        # register code under both prefixed and full type name
+        $types{$self->prefixed($type)} = $types{$type} = [$tag,$types->{$type}];
     }
 
     sub {
